==> avogadro-debuginfo-1.2.0-1.tar.xz: usr/src/debug/avogadro-1.2.0-1/libavogadro/src/tools/qrc_drawtool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/avogadro/avogadro-1.2.0-1.i686/src/avogadro-1.2.0/libavogadro/src/tools/draw.png
  0x0,0x0,0x1,0x4e,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x6,0x0,0x0,0x0,0xc4,0xb4,0x6c,0x3b,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x11,0x0,0x0,0xb,0x11,
  0x1,0x7f,0x64,0x5f,0x91,0x0,0x0,0x1,0x0,0x49,0x44,0x41,0x54,0x78,0x9c,0xad,
  0xd5,0x31,0x8a,0x84,0x30,0x14,0xc6,0xf1,0xbf,0xb0,0x67,0xf0,0x12,0xa6,0x98,0x13,
  0x58,0x58,0x78,0x2,0x21,0xa7,0xf0,0x34,0x16,0x5e,0x41,0xc4,0xc2,0x63,0x68,0x2f,
  0x56,0xb1,0xb1,0xb0,0x8,0x1e,0x41,0x78,0x53,0x65,0x16,0xdc,0x9d,0x19,0x8d,0x3e,
  0x48,0x8a,0x84,0xfc,0xf8,0x5e,0x52,0x24,0xe0,0xa6,0x52,0x4a,0x49,0x14,0x45,0x64,
  0x59,0x46,0x59,0x96,0x4,0x77,0xa1,0x61,0x18,0x52,0x14,0x5,0x79,0x9e,0x3,0x5c,
  0x87,0xff,0x43,0x2f,0xc3,0xef,0x50,0x6b,0xad,0x3f,0xfc,0x9,0x5,0xcf,0xc4,0xdf,
  0xd0,0x61,0x18,0xce,0xc3,0x47,0x50,0x20,0x38,0x5,0x1f,0x45,0x5f,0xd3,0xdd,0xe8,
  0x61,0xf8,0x2c,0x7a,0x8,0xf6,0x41,0xbf,0xc2,0xbe,0xe8,0x47,0xf8,0xa,0xfa,0x76,
  0xe3,0x2a,0xa,0xf0,0xb3,0x5f,0xd0,0x5a,0x53,0x55,0x15,0x7d,0xdf,0x7b,0xa3,0x7f,
  0x4a,0x6b,0x8d,0x31,0x46,0x44,0x44,0x8c,0x31,0xd2,0x75,0x9d,0x24,0x49,0x22,0x4a,
  0x29,0x51,0x4a,0x9,0x20,0x47,0xad,0x57,0x62,0x91,0xdf,0x33,0xd3,0x34,0xb1,0xae,
  0x2b,0x0,0x71,0x1c,0xd3,0x34,0xcd,0xe9,0xa4,0xfb,0xab,0x10,0x87,0xce,0xf3,0xcc,
  0x38,0x8e,0xb4,0x6d,0xeb,0xd7,0xbe,0x4b,0x2b,0x22,0x24,0x49,0x22,0x5d,0xd7,0x49,
  0x5d,0xd7,0xf2,0x78,0x3c,0x4e,0xb5,0xbe,0xaf,0x0,0x20,0x4d,0x53,0xb6,0x6d,0x13,
  0x6b,0x2d,0x6e,0x84,0x61,0x18,0xb8,0x7,0xf3,0x82,0xd3,0x34,0x5,0x60,0x59,0x16,
  0x7,0xdf,0xf2,0x5d,0xe1,0xe0,0xbb,0xeb,0x9,0x8c,0x36,0xe1,0xa8,0xf,0xd1,0xd2,
  0x9f,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // draw
  0x0,0x4,
  0x0,0x6,0xb8,0x87,
  0x0,0x64,
  0x0,0x72,0x0,0x61,0x0,0x77,
    // draw.png
  0x0,0x8,
  0x8,0x8a,0x5a,0x27,
  0x0,0x64,
  0x0,0x72,0x0,0x61,0x0,0x77,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/draw
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/draw/draw.png
  0x0,0x0,0x0,0xe,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_drawtool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_drawtool))

int QT_MANGLE_NAMESPACE(qCleanupResources_drawtool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_drawtool))

==> avogadro-debuginfo-1.2.0-2.tar.xz: usr/src/debug/avogadro-1.2.0-2/libavogadro/src/tools/qrc_drawtool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/avogadro/avogadro-1.2.0-2.x86_64/src/avogadro-1.2.0/libavogadro/src/tools/draw.png
  0x0,0x0,0x1,0x4e,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x6,0x0,0x0,0x0,0xc4,0xb4,0x6c,0x3b,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x11,0x0,0x0,0xb,0x11,
  0x1,0x7f,0x64,0x5f,0x91,0x0,0x0,0x1,0x0,0x49,0x44,0x41,0x54,0x78,0x9c,0xad,
  0xd5,0x31,0x8a,0x84,0x30,0x14,0xc6,0xf1,0xbf,0xb0,0x67,0xf0,0x12,0xa6,0x98,0x13,
  0x58,0x58,0x78,0x2,0x21,0xa7,0xf0,0x34,0x16,0x5e,0x41,0xc4,0xc2,0x63,0x68,0x2f,
  0x56,0xb1,0xb1,0xb0,0x8,0x1e,0x41,0x78,0x53,0x65,0x16,0xdc,0x9d,0x19,0x8d,0x3e,
  0x48,0x8a,0x84,0xfc,0xf8,0x5e,0x52,0x24,0xe0,0xa6,0x52,0x4a,0x49,0x14,0x45,0x64,
  0x59,0x46,0x59,0x96,0x4,0x77,0xa1,0x61,0x18,0x52,0x14,0x5,0x79,0x9e,0x3,0x5c,
  0x87,0xff,0x43,0x2f,0xc3,0xef,0x50,0x6b,0xad,0x3f,0xfc,0x9,0x5,0xcf,0xc4,0xdf,
  0xd0,0x61,0x18,0xce,0xc3,0x47,0x50,0x20,0x38,0x5,0x1f,0x45,0x5f,0xd3,0xdd,0xe8,
  0x61,0xf8,0x2c,0x7a,0x8,0xf6,0x41,0xbf,0xc2,0xbe,0xe8,0x47,0xf8,0xa,0xfa,0x76,
  0xe3,0x2a,0xa,0xf0,0xb3,0x5f,0xd0,0x5a,0x53,0x55,0x15,0x7d,0xdf,0x7b,0xa3,0x7f,
  0x4a,0x6b,0x8d,0x31,0x46,0x44,0x44,0x8c,0x31,0xd2,0x75,0x9d,0x24,0x49,0x22,0x4a,
  0x29,0x51,0x4a,0x9,0x20,0x47,0xad,0x57,0x62,0x91,0xdf,0x33,0xd3,0x34,0xb1,0xae,
  0x2b,0x0,0x71,0x1c,0xd3,0x34,0xcd,0xe9,0xa4,0xfb,0xab,0x10,0x87,0xce,0xf3,0xcc,
  0x38,0x8e,0xb4,0x6d,0xeb,0xd7,0xbe,0x4b,0x2b,0x22,0x24,0x49,0x22,0x5d,0xd7,0x49,
  0x5d,0xd7,0xf2,0x78,0x3c,0x4e,0xb5,0xbe,0xaf,0x0,0x20,0x4d,0x53,0xb6,0x6d,0x13,
  0x6b,0x2d,0x6e,0x84,0x61,0x18,0xb8,0x7,0xf3,0x82,0xd3,0x34,0x5,0x60,0x59,0x16,
  0x7,0xdf,0xf2,0x5d,0xe1,0xe0,0xbb,0xeb,0x9,0x8c,0x36,0xe1,0xa8,0xf,0xd1,0xd2,
  0x9f,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // draw
  0x0,0x4,
  0x0,0x6,0xb8,0x87,
  0x0,0x64,
  0x0,0x72,0x0,0x61,0x0,0x77,
    // draw.png
  0x0,0x8,
  0x8,0x8a,0x5a,0x27,
  0x0,0x64,
  0x0,0x72,0x0,0x61,0x0,0x77,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/draw
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/draw/draw.png
  0x0,0x0,0x0,0xe,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_drawtool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_drawtool))

int QT_MANGLE_NAMESPACE(qCleanupResources_drawtool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_drawtool))
